import { Component } from "@angular/core"

@Component({
    selector: "user-admin",
    templateUrl: "user.component.html",
})
export class UserComponent {
}
